@@ -10,17 +10,17 @@ use Readonly;
 # Constants.
 Readonly::Array our @EXPORT => qw(parse_java_jdk_release);
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 # Parse Java JDK release.
 sub parse_java_jdk_release {
 	my $release_name = shift;
 
 	my $release_hr = {};
-	if ($release_name =~ m/^jdk-([0-9]+)(u([0-9]+))?-linux-(i586|x64|amd64|arm-vfp-hflt)\.(bin|tar\.gz)$/ms) {
-		$release_hr->{j2se_arch} = $4;
+	if ($release_name =~ m/^jdk-([0-9]+)(u([0-9]+))?-linux-(i586|x64|amd64|arm-vfp-hflt|arm32-vfp-hflt|arm64-vfp-hflt)\.(bin|tar\.gz)$/ms) {
 		$release_hr->{j2se_release} = $1;
 		$release_hr->{j2se_update} = $3;
+		$release_hr->{j2se_arch} = $4;
 		$release_hr->{j2se_version} = $release_hr->{j2se_release};
 		$release_hr->{j2se_version_name} = $release_hr->{j2se_release};
 		if ($release_hr->{j2se_update}) {
@@ -31,15 +31,22 @@ sub parse_java_jdk_release {
 		} else {
 			$release_hr->{j2se_version_name} .= ' GA';
 		}
-	} elsif ($release_name =~ m/^jdk-([0-9]+)\.([0-9]+)\.([0-9]+)(\.([0-9]+))?_linux-(i586|x64|amd64|arm-vfp-hflt)_bin.tar.gz$/ms) {
-		$release_hr->{j2se_arch} = $6;
+	} elsif ($release_name =~ m/^jdk-([0-9]+)(\.([0-9]+))?(\.([0-9]+))?(\.([0-9]+))?_linux-(i586|x64|amd64|arm-vfp-hflt|arm32-vfp-hflt|arm64-vfp-hflt)_bin.tar.gz$/ms) {
 		$release_hr->{j2se_release} = $1;
-		$release_hr->{j2se_update} = $3;
-		$release_hr->{j2se_interim} = $2;
-		$release_hr->{j2se_patch} = $5;
-		$release_hr->{j2se_version} = $release_hr->{j2se_release}.'.'.
-			$release_hr->{j2se_interim}.'.'.
-			$release_hr->{j2se_update};
+		$release_hr->{j2se_interim} = $3;
+		$release_hr->{j2se_update} = $5;
+		$release_hr->{j2se_patch} = $7;
+		$release_hr->{j2se_arch} = $8;
+		$release_hr->{j2se_version} = $release_hr->{j2se_release};
+		if (defined $release_hr->{j2se_interim}) {
+			$release_hr->{j2se_version} .= '.'.$release_hr->{j2se_interim};
+			if (defined $release_hr->{j2se_update}) {
+				$release_hr->{j2se_version} .= '.'.$release_hr->{j2se_update};
+				if (defined $release_hr->{j2se_patch}) {
+					$release_hr->{j2se_version} .= '.'.$release_hr->{j2se_patch};
+				}
+			}
+		}
 		$release_hr->{j2se_version_name} = $release_hr->{j2se_release};
 		if ($release_hr->{j2se_update}) {
 			$release_hr->{j2se_version_name}
@@ -139,6 +146,6 @@ Thanks for L<java-package|https://salsa.debian.org/java-team/java-package.git> p
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
